@@ -2,7 +2,7 @@ from spiderlib import *
 
 def test01():
     spider = Spider("美国国防部", pipeline=MySQLPipeline())
-    spider.list(urls="https://www.defense.gov/Newsroom/", expresses={"title":"//a[@class='title']//text()", "link":"//a[@class='title']//@href"}, fields={"title":"title", "url":"link"})
+    spider.list(urls="https://www.defense.gov/Newsroom/", expresses={"title":"//a[@class='title']//text()", "link":"//a[@class='title']//@href"}, fields={"title":"title", "text":"link"})
     spider.run()
 
 
@@ -13,4 +13,5 @@ def test02():
     spider.run()
 
 
+test01()
 test01()
\ No newline at end of file
